#if   ( F_CPU >= 1000000UL ) && ( F_CPU <= 10900000UL )
#	define PRESCALER_VALUE		1
#	define PRESCALER_BITMASK	(0<<CS12) | (0<<CS11) | (1<<CS10);
#elif ( F_CPU >= 8000000UL ) && ( F_CPU <= 87200000UL )
#	define PRESCALER_VALUE		8
#	define PRESCALER_BITMASK	(0<<CS12) | (1<<CS11) | (0<<CS10);
#else
#	error F_CPU not supported
#endif

/*
* Sample program to test the DHT11+22.c lib
*
* DHT11 and DHT22 are sensors for air-humidity and temperature,
* which use a proprietary serial data protocol.
*/

#include <avr/io.h>
#include <stdio.h>
#include <stdlib.h>
#include <avr/pgmspace.h>
#include <avr/interrupt.h>
#include <util/delay.h>

#include "LCD_I2C.h"

#include "DHT11+22.h"


int main( void)
{
	char strval[8];

	sei();

	// init lcd
	i2c_init();
	lcd_init( LCD_DISP_ON);
	lcd_led( 1);

	lcd_clrscr();
	lcd_home();
	lcd_puts( "DHT11-Test");

	
	uint16_t x = 55555;
	uint16_t y = 1000L * x  / ( F_CPU / PRESCALER_VALUE / 1000 );	//  check
	
	lcd_clrscr(); lcd_home();
	lcd_puts( "x = ");
	utoa( x, strval, 10);
	lcd_puts( strval);
	lcd_puts( "\n");
	lcd_puts( "y = ");
	utoa( y, strval, 10);
	lcd_puts( strval);
	lcd_puts( "\n");

	while ( 1 )
	{
		_delay_ms( 2000);		// the DHT11 should not be acquired a) within 1s after power on and b) more then once per 2s
		acquire_DHT();
	
		lcd_clrscr(); lcd_home();
		lcd_puts( "Temperatur = ");
		itoa( get_temperature(), strval, 10);
		lcd_puts( strval);
		lcd_puts( "C\r\n");
		
		lcd_puts( "Feuchte    = ");
		itoa( get_humidity(), strval, 10);
		lcd_puts( strval);
		lcd_puts( "%");
	}
}